pub struct ClusterControlPlaneRef {
pub api_group: String,
pub kind: String,
pub name: String,
}Expand description
controlPlaneRef is an optional reference to a provider-specific resource that holds the details for provisioning the Control Plane for a Cluster.
Fields
api_group: StringapiGroup is the group of the resource being referenced. apiGroup must be fully qualified domain name. The corresponding version for this reference will be looked up from the contract labels of the corresponding CRD of the resource being referenced.
kind: Stringkind of the resource being referenced. kind must consist of alphanumeric characters or ‘-’, start with an alphabetic character, and end with an alphanumeric character.
name: Stringname of the resource being referenced. name must consist of lower case alphanumeric characters, ‘-’ or ‘.’, and must start and end with an alphanumeric character.