pub struct ClusterStatus {
pub conditions: Option<Vec<Condition>>,
pub control_plane: Option<ClusterStatusControlPlane>,
pub deprecated: Option<ClusterStatusDeprecated>,
pub failure_domains: Option<Vec<ClusterStatusFailureDomains>>,
pub initialization: Option<ClusterStatusInitialization>,
pub observed_generation: Option<i64>,
pub phase: Option<ClusterStatusPhase>,
pub workers: Option<ClusterStatusWorkers>,
}Expand description
status is the observed state of Cluster.
Fields
conditions: Option<Vec<Condition>>conditions represents the observations of a Cluster’s current state. Known condition types are Available, InfrastructureReady, ControlPlaneInitialized, ControlPlaneAvailable, WorkersAvailable, MachinesReady MachinesUpToDate, RemoteConnectionProbe, ScalingUp, ScalingDown, Remediating, Deleting, Paused. Additionally, a TopologyReconciled condition will be added in case the Cluster is referencing a ClusterClass / defining a managed Topology.
control_plane: Option<ClusterStatusControlPlane>controlPlane groups all the observations about Cluster’s ControlPlane current state.
deprecated: Option<ClusterStatusDeprecated>deprecated groups all the status fields that are deprecated and will be removed when all the nested field are removed.
failure_domains: Option<Vec<ClusterStatusFailureDomains>>failureDomains is a slice of failure domain objects synced from the infrastructure provider.
initialization: Option<ClusterStatusInitialization>initialization provides observations of the Cluster initialization process. NOTE: Fields in this struct are part of the Cluster API contract and are used to orchestrate initial Cluster provisioning.
observed_generation: Option<i64>observedGeneration is the latest generation observed by the controller.
phase: Option<ClusterStatusPhase>phase represents the current phase of cluster actuation.
workers: Option<ClusterStatusWorkers>workers groups all the observations about Cluster’s Workers current state.