pub struct ClusterStatusControlPlane {
pub available_replicas: Option<i32>,
pub desired_replicas: Option<i32>,
pub ready_replicas: Option<i32>,
pub replicas: Option<i32>,
pub up_to_date_replicas: Option<i32>,
}Expand description
controlPlane groups all the observations about Cluster’s ControlPlane current state.
Fields
available_replicas: Option<i32>availableReplicas is the total number of available control plane machines in this cluster. A machine is considered available when Machine’s Available condition is true.
desired_replicas: Option<i32>desiredReplicas is the total number of desired control plane machines in this cluster.
ready_replicas: Option<i32>readyReplicas is the total number of ready control plane machines in this cluster. A machine is considered ready when Machine’s Ready condition is true.
replicas: Option<i32>replicas is the total number of control plane machines in this cluster. NOTE: replicas also includes machines still being provisioned or being deleted.
up_to_date_replicas: Option<i32>upToDateReplicas is the number of up-to-date control plane machines in this cluster. A machine is considered up-to-date when Machine’s UpToDate condition is true.