pub struct ClusterStatusDeprecatedV1beta1 {
pub conditions: Option<Vec<Condition>>,
pub failure_message: Option<String>,
pub failure_reason: Option<String>,
}Expand description
v1beta1 groups all the status fields that are deprecated and will be removed when support for v1beta1 will be dropped.
Fields
conditions: Option<Vec<Condition>>conditions defines current service state of the cluster.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
failure_message: Option<String>failureMessage indicates that there is a fatal problem reconciling the state, and will be set to a descriptive error message.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
failure_reason: Option<String>failureReason indicates that there is a fatal problem reconciling the state, and will be set to a token value suitable for programmatic interpretation.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.