pub struct ClusterStatusInitialization {
pub control_plane_initialized: Option<bool>,
pub infrastructure_provisioned: Option<bool>,
}Expand description
initialization provides observations of the Cluster initialization process. NOTE: Fields in this struct are part of the Cluster API contract and are used to orchestrate initial Cluster provisioning.
Fields
control_plane_initialized: Option<bool>controlPlaneInitialized denotes when the control plane is functional enough to accept requests. This information is usually used as a signal for starting all the provisioning operations that depends on a functional API server, but do not require a full HA control plane to exists, like e.g. join worker Machines, install core addons like CNI, CPI, CSI etc. NOTE: this field is part of the Cluster API contract, and it is used to orchestrate provisioning. The value of this field is never updated after initialization is completed.
infrastructure_provisioned: Option<bool>infrastructureProvisioned is true when the infrastructure provider reports that Cluster’s infrastructure is fully provisioned. NOTE: this field is part of the Cluster API contract, and it is used to orchestrate provisioning. The value of this field is never updated after provisioning is completed.