pub struct ClusterTopologyControlPlane {
pub deletion: Option<ClusterTopologyControlPlaneDeletion>,
pub health_check: Option<ClusterTopologyControlPlaneHealthCheck>,
pub metadata: Option<ClusterTopologyControlPlaneMetadata>,
pub readiness_gates: Option<Vec<ClusterTopologyControlPlaneReadinessGates>>,
pub replicas: Option<i32>,
pub variables: Option<ClusterTopologyControlPlaneVariables>,
}Expand description
controlPlane describes the cluster control plane.
Fields
deletion: Option<ClusterTopologyControlPlaneDeletion>deletion contains configuration options for Machine deletion.
health_check: Option<ClusterTopologyControlPlaneHealthCheck>healthCheck allows to enable, disable and override control plane health check configuration from the ClusterClass for this control plane.
metadata: Option<ClusterTopologyControlPlaneMetadata>metadata is the metadata applied to the ControlPlane and the Machines of the ControlPlane if the ControlPlaneTemplate referenced by the ClusterClass is machine based. If not, it is applied only to the ControlPlane. At runtime this metadata is merged with the corresponding metadata from the ClusterClass.
readiness_gates: Option<Vec<ClusterTopologyControlPlaneReadinessGates>>readinessGates specifies additional conditions to include when evaluating Machine Ready condition.
This field can be used e.g. to instruct the machine controller to include in the computation for Machine’s ready computation a condition, managed by an external controllers, reporting the status of special software/hardware installed on the Machine.
If this field is not defined, readinessGates from the corresponding ControlPlaneClass will be used, if any.
NOTE: Specific control plane provider implementations might automatically extend the list of readinessGates; e.g. the kubeadm control provider adds ReadinessGates for the APIServerPodHealthy, SchedulerPodHealthy conditions, etc.
replicas: Option<i32>replicas is the number of control plane nodes. If the value is not set, the ControlPlane object is created without the number of Replicas and it’s assumed that the control plane controller does not implement support for this field. When specified against a control plane provider that lacks support for this field, this value will be ignored.
variables: Option<ClusterTopologyControlPlaneVariables>variables can be used to customize the ControlPlane through patches.