pub struct ClusterTopologyControlPlaneHealthCheckRemediation {
pub template_ref: Option<ClusterTopologyControlPlaneHealthCheckRemediationTemplateRef>,
pub trigger_if: Option<ClusterTopologyControlPlaneHealthCheckRemediationTriggerIf>,
}Expand description
remediation configures if and how remediations are triggered if a Machine is unhealthy.
If one of checks and remediation fields are set, the system assumes that an healthCheck override is defined, and as a consequence the checks and remediation fields from cluster will be used instead of the corresponding fields in ClusterClass.
If an health check override is defined and remediation or remediation.triggerIf is not set, remediation will always be triggered for unhealthy Machines.
If an health check override is defined and remediation or remediation.templateRef is not set, the OwnerRemediated condition will be set on unhealthy Machines to trigger remediation via the owner of the Machines, for example a MachineSet or a KubeadmControlPlane.
Fields
template_ref: Option<ClusterTopologyControlPlaneHealthCheckRemediationTemplateRef>templateRef is a reference to a remediation template provided by an infrastructure provider.
This field is completely optional, when filled, the MachineHealthCheck controller creates a new object from the template referenced and hands off remediation of the machine to a controller that lives outside of Cluster API.
trigger_if: Option<ClusterTopologyControlPlaneHealthCheckRemediationTriggerIf>triggerIf configures if remediations are triggered. If this field is not set, remediations are always triggered.