ClusterTopologyWorkersMachineDeploymentsHealthCheckChecks

Struct ClusterTopologyWorkersMachineDeploymentsHealthCheckChecks 

pub struct ClusterTopologyWorkersMachineDeploymentsHealthCheckChecks {
    pub node_startup_timeout_seconds: Option<i32>,
    pub unhealthy_machine_conditions: Option<Vec<ClusterTopologyWorkersMachineDeploymentsHealthCheckChecksUnhealthyMachineConditions>>,
    pub unhealthy_node_conditions: Option<Vec<ClusterTopologyWorkersMachineDeploymentsHealthCheckChecksUnhealthyNodeConditions>>,
}
checks are the checks that are used to evaluate if a Machine is healthy.

If one of checks and remediation fields are set, the system assumes that an healthCheck override is defined, and as a consequence the checks and remediation fields from Cluster will be used instead of the corresponding fields in ClusterClass.

Independent of this configuration the MachineHealthCheck controller will always flag Machines with cluster.x-k8s.io/remediate-machine annotation and Machines with deleted Nodes as unhealthy.

Furthermore, if checks.nodeStartupTimeoutSeconds is not set it is defaulted to 10 minutes and evaluated accordingly.

Fields

node_startup_timeout_seconds: Option<i32>

nodeStartupTimeoutSeconds allows to set the maximum time for MachineHealthCheck to consider a Machine unhealthy if a corresponding Node isn’t associated through a Spec.ProviderID field.

The duration set in this field is compared to the greatest of:

  • Cluster’s infrastructure ready condition timestamp (if and when available)
  • Control Plane’s initialized condition timestamp (if and when available)
  • Machine’s infrastructure ready condition timestamp (if and when available)
  • Machine’s metadata creation timestamp

Defaults to 10 minutes. If you wish to disable this feature, set the value explicitly to 0.

unhealthy_machine_conditions: Option<Vec<ClusterTopologyWorkersMachineDeploymentsHealthCheckChecksUnhealthyMachineConditions>>

unhealthyMachineConditions contains a list of the machine conditions that determine whether a machine is considered unhealthy. The conditions are combined in a logical OR, i.e. if any of the conditions is met, the machine is unhealthy.

unhealthy_node_conditions: Option<Vec<ClusterTopologyWorkersMachineDeploymentsHealthCheckChecksUnhealthyNodeConditions>>

unhealthyNodeConditions contains a list of conditions that determine whether a node is considered unhealthy. The conditions are combined in a logical OR, i.e. if any of the conditions is met, the node is unhealthy.