pub struct ClusterClassControlPlaneHealthCheck {
pub checks: Option<ClusterClassControlPlaneHealthCheckChecks>,
pub remediation: Option<ClusterClassControlPlaneHealthCheckRemediation>,
}Expand description
healthCheck defines a MachineHealthCheck for this ControlPlaneClass. This field is supported if and only if the ControlPlane provider template referenced above is Machine based and supports setting replicas.
Fields
checks: Option<ClusterClassControlPlaneHealthCheckChecks>checks are the checks that are used to evaluate if a Machine is healthy.
Independent of this configuration the MachineHealthCheck controller will always
flag Machines with cluster.x-k8s.io/remediate-machine annotation and
Machines with deleted Nodes as unhealthy.
Furthermore, if checks.nodeStartupTimeoutSeconds is not set it is defaulted to 10 minutes and evaluated accordingly.
remediation: Option<ClusterClassControlPlaneHealthCheckRemediation>remediation configures if and how remediations are triggered if a Machine is unhealthy.
If remediation or remediation.triggerIf is not set, remediation will always be triggered for unhealthy Machines.
If remediation or remediation.templateRef is not set, the OwnerRemediated condition will be set on unhealthy Machines to trigger remediation via the owner of the Machines, for example a MachineSet or a KubeadmControlPlane.