pub struct ClusterClassControlPlaneHealthCheckChecksUnhealthyMachineConditions {
pub status: ClusterClassControlPlaneHealthCheckChecksUnhealthyMachineConditionsStatus,
pub timeout_seconds: i32,
pub type: String,
}Expand description
UnhealthyMachineCondition represents a Machine condition type and value with a timeout specified as a duration. When the named condition has been in the given status for at least the timeout value, a machine is considered unhealthy.
Fields
status: ClusterClassControlPlaneHealthCheckChecksUnhealthyMachineConditionsStatusstatus of the condition, one of True, False, Unknown.
timeout_seconds: i32timeoutSeconds is the duration that a machine must be in a given status for, after which the machine is considered unhealthy. For example, with a value of “3600”, the machine must match the status for at least 1 hour before being considered unhealthy.
type: Stringtype of Machine condition