pub struct ClusterClassControlPlaneHealthCheckRemediation {
pub template_ref: Option<ClusterClassControlPlaneHealthCheckRemediationTemplateRef>,
pub trigger_if: Option<ClusterClassControlPlaneHealthCheckRemediationTriggerIf>,
}Expand description
remediation configures if and how remediations are triggered if a Machine is unhealthy.
If remediation or remediation.triggerIf is not set, remediation will always be triggered for unhealthy Machines.
If remediation or remediation.templateRef is not set, the OwnerRemediated condition will be set on unhealthy Machines to trigger remediation via the owner of the Machines, for example a MachineSet or a KubeadmControlPlane.
Fields
template_ref: Option<ClusterClassControlPlaneHealthCheckRemediationTemplateRef>templateRef is a reference to a remediation template provided by an infrastructure provider.
This field is completely optional, when filled, the MachineHealthCheck controller creates a new object from the template referenced and hands off remediation of the machine to a controller that lives outside of Cluster API.
trigger_if: Option<ClusterClassControlPlaneHealthCheckRemediationTriggerIf>triggerIf configures if remediations are triggered. If this field is not set, remediations are always triggered.