pub struct ClusterClassInfrastructure {
pub naming: Option<ClusterClassInfrastructureNaming>,
pub template_ref: ClusterClassInfrastructureTemplateRef,
}Expand description
infrastructure is a reference to a local struct that holds the details for provisioning the infrastructure cluster for the Cluster.
Fields
naming: Option<ClusterClassInfrastructureNaming>naming allows changing the naming pattern used when creating the infrastructure cluster object.
template_ref: ClusterClassInfrastructureTemplateReftemplateRef contains the reference to a provider-specific infrastructure cluster template.