pub struct ClusterClassStatus {
pub conditions: Option<Vec<Condition>>,
pub deprecated: Option<ClusterClassStatusDeprecated>,
pub observed_generation: Option<i64>,
pub variables: Option<Vec<ClusterClassStatusVariables>>,
}Expand description
status is the observed state of ClusterClass.
Fields
conditions: Option<Vec<Condition>>conditions represents the observations of a ClusterClass’s current state. Known condition types are VariablesReady, RefVersionsUpToDate, Paused.
deprecated: Option<ClusterClassStatusDeprecated>deprecated groups all the status fields that are deprecated and will be removed when all the nested field are removed.
observed_generation: Option<i64>observedGeneration is the latest generation observed by the controller.
variables: Option<Vec<ClusterClassStatusVariables>>variables is a list of ClusterClassStatusVariable that are defined for the ClusterClass.