pub struct ClusterClassStatusVariablesDefinitionsDeprecatedV1Beta1Metadata {
pub annotations: Option<BTreeMap<String, String>>,
pub labels: Option<BTreeMap<String, String>>,
}Expand description
deprecatedV1Beta1Metadata is the metadata of a variable. It can be used to add additional data for higher level tools to a ClusterClassVariable.
Deprecated: This field is deprecated and will be removed when support for v1beta1 will be dropped. Please use XMetadata in JSONSchemaProps instead.
Fields
annotations: Option<BTreeMap<String, String>>annotations is an unstructured key value map that can be used to store and retrieve arbitrary metadata. They are not queryable.
labels: Option<BTreeMap<String, String>>labels is a map of string keys and values that can be used to organize and categorize (scope and select) variables.