pub struct ClusterClassWorkersMachineDeploymentsHealthCheckRemediation {
pub max_in_flight: Option<IntOrString>,
pub template_ref: Option<ClusterClassWorkersMachineDeploymentsHealthCheckRemediationTemplateRef>,
pub trigger_if: Option<ClusterClassWorkersMachineDeploymentsHealthCheckRemediationTriggerIf>,
}Expand description
remediation configures if and how remediations are triggered if a Machine is unhealthy.
If remediation or remediation.triggerIf is not set, remediation will always be triggered for unhealthy Machines.
If remediation or remediation.templateRef is not set, the OwnerRemediated condition will be set on unhealthy Machines to trigger remediation via the owner of the Machines, for example a MachineSet or a KubeadmControlPlane.
Fields
max_in_flight: Option<IntOrString>maxInFlight determines how many in flight remediations should happen at the same time.
Remediation only happens on the MachineSet with the most current revision, while older MachineSets (usually present during rollout operations) aren’t allowed to remediate.
Note: In general (independent of remediations), unhealthy machines are always prioritized during scale down operations over healthy ones.
MaxInFlight can be set to a fixed number or a percentage. Example: when this is set to 20%, the MachineSet controller deletes at most 20% of the desired replicas.
If not set, remediation is limited to all machines (bounded by replicas) under the active MachineSet’s management.
template_ref: Option<ClusterClassWorkersMachineDeploymentsHealthCheckRemediationTemplateRef>templateRef is a reference to a remediation template provided by an infrastructure provider.
This field is completely optional, when filled, the MachineHealthCheck controller creates a new object from the template referenced and hands off remediation of the machine to a controller that lives outside of Cluster API.
trigger_if: Option<ClusterClassWorkersMachineDeploymentsHealthCheckRemediationTriggerIf>triggerIf configures if remediations are triggered. If this field is not set, remediations are always triggered.