pub struct ClusterClassWorkersMachineDeploymentsHealthCheckRemediationTemplateRef {
pub api_version: String,
pub kind: String,
pub name: String,
}Expand description
templateRef is a reference to a remediation template provided by an infrastructure provider.
This field is completely optional, when filled, the MachineHealthCheck controller creates a new object from the template referenced and hands off remediation of the machine to a controller that lives outside of Cluster API.
Fields
api_version: StringapiVersion of the remediation template. apiVersion must be fully qualified domain name followed by / and a version. NOTE: This field must be kept in sync with the APIVersion of the remediation template.
kind: Stringkind of the remediation template. kind must consist of alphanumeric characters or ‘-’, start with an alphabetic character, and end with an alphanumeric character.
name: Stringname of the remediation template. name must consist of lower case alphanumeric characters, ‘-’ or ‘.’, and must start and end with an alphanumeric character.