pub struct ClusterClassWorkersMachineDeploymentsInfrastructureTemplateRef {
pub api_version: String,
pub kind: String,
pub name: String,
}Expand description
templateRef is a required reference to the InfrastructureTemplate for a MachineDeployment.
Fields
api_version: StringapiVersion of the template. apiVersion must be fully qualified domain name followed by / and a version.
kind: Stringkind of the template. kind must consist of alphanumeric characters or ‘-’, start with an alphabetic character, and end with an alphanumeric character.
name: Stringname of the template. name must consist of lower case alphanumeric characters, ‘-’ or ‘.’, and must start and end with an alphanumeric character.