ClusterClassWorkersMachinePools

Struct ClusterClassWorkersMachinePools 

pub struct ClusterClassWorkersMachinePools {
    pub bootstrap: ClusterClassWorkersMachinePoolsBootstrap,
    pub class: String,
    pub deletion: Option<ClusterClassWorkersMachinePoolsDeletion>,
    pub failure_domains: Option<Vec<String>>,
    pub infrastructure: ClusterClassWorkersMachinePoolsInfrastructure,
    pub metadata: Option<ClusterClassWorkersMachinePoolsMetadata>,
    pub min_ready_seconds: Option<i32>,
    pub naming: Option<ClusterClassWorkersMachinePoolsNaming>,
}
MachinePoolClass serves as a template to define a pool of worker nodes of the cluster provisioned using ClusterClass.

Fields

bootstrap: ClusterClassWorkersMachinePoolsBootstrap

bootstrap contains the bootstrap template reference to be used for the creation of the Machines in the MachinePool.

class: String

class denotes a type of machine pool present in the cluster, this name MUST be unique within a ClusterClass and can be referenced in the Cluster to create a managed MachinePool.

deletion: Option<ClusterClassWorkersMachinePoolsDeletion>

deletion contains configuration options for Machine deletion.

failure_domains: Option<Vec<String>>

failureDomains is the list of failure domains the MachinePool should be attached to. Must match a key in the FailureDomains map stored on the cluster object. NOTE: This value can be overridden while defining a Cluster.Topology using this MachinePoolClass.

infrastructure: ClusterClassWorkersMachinePoolsInfrastructure

infrastructure contains the infrastructure template reference to be used for the creation of the MachinePool.

metadata: Option<ClusterClassWorkersMachinePoolsMetadata>

metadata is the metadata applied to the MachinePool. At runtime this metadata is merged with the corresponding metadata from the topology.

min_ready_seconds: Option<i32>

minReadySeconds is the minimum number of seconds for which a newly created machine pool should be ready. Defaults to 0 (machine will be considered available as soon as it is ready) NOTE: This value can be overridden while defining a Cluster.Topology using this MachinePoolClass.

naming: Option<ClusterClassWorkersMachinePoolsNaming>

naming allows changing the naming pattern used when creating the MachinePool.