pub struct ClusterClassWorkersMachinePoolsBootstrap {
pub template_ref: ClusterClassWorkersMachinePoolsBootstrapTemplateRef,
}Expand description
bootstrap contains the bootstrap template reference to be used for the creation of the Machines in the MachinePool.
Fields
template_ref: ClusterClassWorkersMachinePoolsBootstrapTemplateReftemplateRef is a required reference to the BootstrapTemplate for a MachinePool.