pub struct ClusterClassWorkersMachinePoolsDeletion {
pub node_deletion_timeout_seconds: Option<i32>,
pub node_drain_timeout_seconds: Option<i32>,
pub node_volume_detach_timeout_seconds: Option<i32>,
}Expand description
deletion contains configuration options for Machine deletion.
Fields
node_deletion_timeout_seconds: Option<i32>nodeDeletionTimeoutSeconds defines how long the controller will attempt to delete the Node that the Machine hosts after the Machine Pool is marked for deletion. A duration of 0 will retry deletion indefinitely. Defaults to 10 seconds. NOTE: This value can be overridden while defining a Cluster.Topology using this MachinePoolClass.
node_drain_timeout_seconds: Option<i32>nodeDrainTimeoutSeconds is the total amount of time that the controller will spend on draining a node.
The default value is 0, meaning that the node can be drained without any time limitations.
NOTE: nodeDrainTimeoutSeconds is different from kubectl drain --timeout
NOTE: This value can be overridden while defining a Cluster.Topology using this MachinePoolClass.
node_volume_detach_timeout_seconds: Option<i32>nodeVolumeDetachTimeoutSeconds is the total amount of time that the controller will spend on waiting for all volumes to be detached. The default value is 0, meaning that the volumes can be detached without any time limitations. NOTE: This value can be overridden while defining a Cluster.Topology using this MachinePoolClass.