pub struct ClusterClassWorkersMachinePoolsMetadata {
pub annotations: Option<BTreeMap<String, String>>,
pub labels: Option<BTreeMap<String, String>>,
}Expand description
metadata is the metadata applied to the MachinePool. At runtime this metadata is merged with the corresponding metadata from the topology.
Fields
annotations: Option<BTreeMap<String, String>>annotations is an unstructured key value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: http://kubernetes.io/docs/user-guide/annotations
labels: Option<BTreeMap<String, String>>labels is a map of string keys and values that can be used to organize and categorize (scope and select) objects. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels