pub struct ClusterClassWorkersMachinePoolsNaming {
pub template: Option<String>,
}Expand description
naming allows changing the naming pattern used when creating the MachinePool.
Fields
template: Option<String>template defines the template to use for generating the name of the MachinePool object.
If not defined, it will fallback to {{ .cluster.name }}-{{ .machinePool.topologyName }}-{{ .random }}.
If the templated string exceeds 63 characters, it will be trimmed to 58 characters and will
get concatenated with a random suffix of length 5.
The templating mechanism provides the following arguments:
.cluster.name: The name of the cluster object..random: A random alphanumeric string, without vowels, of length 5..machinePool.topologyName: The name of the MachinePool topology (Cluster.spec.topology.workers.machinePools[].name).