pub struct ClusterResourceSetStatus {
pub conditions: Option<Vec<Condition>>,
pub deprecated: Option<ClusterResourceSetStatusDeprecated>,
pub observed_generation: Option<i64>,
}Expand description
status is the observed state of ClusterResourceSet.
Fields
conditions: Option<Vec<Condition>>conditions represents the observations of a ClusterResourceSet’s current state. Known condition types are ResourcesApplied.
deprecated: Option<ClusterResourceSetStatusDeprecated>deprecated groups all the status fields that are deprecated and will be removed when all the nested field are removed.
observed_generation: Option<i64>observedGeneration reflects the generation of the most recently observed ClusterResourceSet.