pub struct ExtensionConfigStatusDeprecated {
pub v1beta1: Option<ExtensionConfigStatusDeprecatedV1beta1>,
}Expand description
deprecated groups all the status fields that are deprecated and will be removed when all the nested field are removed.
Fields
v1beta1: Option<ExtensionConfigStatusDeprecatedV1beta1>v1beta1 groups all the status fields that are deprecated and will be removed when support for v1beta1 will be dropped.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.