pub struct ExtensionConfigStatusDeprecatedV1beta1 {
pub conditions: Option<Vec<Condition>>,
}Expand description
v1beta1 groups all the status fields that are deprecated and will be removed when support for v1beta1 will be dropped.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
Fields
conditions: Option<Vec<Condition>>conditions defines current service state of the ExtensionConfig.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.