pub struct IpAddressPoolRef {
pub api_group: String,
pub kind: String,
pub name: String,
}Expand description
poolRef is a reference to the pool that this IPAddress was created from.
Fields
api_group: StringapiGroup of the IPPool. apiGroup must be fully qualified domain name.
kind: Stringkind of the IPPool. kind must consist of alphanumeric characters or ‘-’, start with an alphabetic character, and end with an alphanumeric character.
name: Stringname of the IPPool. name must consist of lower case alphanumeric characters, ‘-’ or ‘.’, and must start and end with an alphanumeric character.