pub struct IpAddressClaimStatus {
pub address_ref: Option<IpAddressClaimStatusAddressRef>,
pub conditions: Option<Vec<Condition>>,
pub deprecated: Option<IpAddressClaimStatusDeprecated>,
}Expand description
status is the observed state of IPAddressClaim.
Fields
address_ref: Option<IpAddressClaimStatusAddressRef>addressRef is a reference to the address that was created for this claim.
conditions: Option<Vec<Condition>>conditions represents the observations of a IPAddressClaim’s current state. Known condition types are Ready.
deprecated: Option<IpAddressClaimStatusDeprecated>deprecated groups all the status fields that are deprecated and will be removed when all the nested field are removed.