pub struct MachineStatus {
pub addresses: Option<Vec<MachineStatusAddresses>>,
pub certificates_expiry_date: Option<String>,
pub conditions: Option<Vec<Condition>>,
pub deletion: Option<MachineStatusDeletion>,
pub deprecated: Option<MachineStatusDeprecated>,
pub initialization: Option<MachineStatusInitialization>,
pub last_updated: Option<String>,
pub node_info: Option<MachineStatusNodeInfo>,
pub node_ref: Option<MachineStatusNodeRef>,
pub observed_generation: Option<i64>,
pub phase: Option<MachineStatusPhase>,
}Expand description
status is the observed state of Machine.
Fields
addresses: Option<Vec<MachineStatusAddresses>>addresses is a list of addresses assigned to the machine. This field is copied from the infrastructure provider reference.
certificates_expiry_date: Option<String>certificatesExpiryDate is the expiry date of the machine certificates. This value is only set for control plane machines.
conditions: Option<Vec<Condition>>conditions represents the observations of a Machine’s current state. Known condition types are Available, Ready, UpToDate, BootstrapConfigReady, InfrastructureReady, NodeReady, NodeHealthy, Updating, Deleting, Paused. If a MachineHealthCheck is targeting this machine, also HealthCheckSucceeded, OwnerRemediated conditions are added. Additionally control plane Machines controlled by KubeadmControlPlane will have following additional conditions: APIServerPodHealthy, ControllerManagerPodHealthy, SchedulerPodHealthy, EtcdPodHealthy, EtcdMemberHealthy.
deletion: Option<MachineStatusDeletion>deletion contains information relating to removal of the Machine. Only present when the Machine has a deletionTimestamp and drain or wait for volume detach started.
deprecated: Option<MachineStatusDeprecated>deprecated groups all the status fields that are deprecated and will be removed when all the nested field are removed.
initialization: Option<MachineStatusInitialization>initialization provides observations of the Machine initialization process. NOTE: Fields in this struct are part of the Cluster API contract and are used to orchestrate initial Machine provisioning.
last_updated: Option<String>lastUpdated identifies when the phase of the Machine last transitioned.
node_info: Option<MachineStatusNodeInfo>nodeInfo is a set of ids/uuids to uniquely identify the node. More info: https://kubernetes.io/docs/concepts/nodes/node/#info
node_ref: Option<MachineStatusNodeRef>nodeRef will point to the corresponding Node if it exists.
observed_generation: Option<i64>observedGeneration is the latest generation observed by the controller.
phase: Option<MachineStatusPhase>phase represents the current phase of machine actuation.