pub struct MachineStatusInitialization {
pub bootstrap_data_secret_created: Option<bool>,
pub infrastructure_provisioned: Option<bool>,
}Expand description
initialization provides observations of the Machine initialization process. NOTE: Fields in this struct are part of the Cluster API contract and are used to orchestrate initial Machine provisioning.
Fields
bootstrap_data_secret_created: Option<bool>bootstrapDataSecretCreated is true when the bootstrap provider reports that the Machine’s boostrap secret is created. NOTE: this field is part of the Cluster API contract, and it is used to orchestrate provisioning. The value of this field is never updated after provisioning is completed.
infrastructure_provisioned: Option<bool>infrastructureProvisioned is true when the infrastructure provider reports that Machine’s infrastructure is fully provisioned. NOTE: this field is part of the Cluster API contract, and it is used to orchestrate provisioning. The value of this field is never updated after provisioning is completed.