pub struct MachineStatusNodeRef {
pub name: String,
}Expand description
nodeRef will point to the corresponding Node if it exists.
Fields
name: Stringname of the node. name must consist of lower case alphanumeric characters, ‘-’ or ‘.’, and must start and end with an alphanumeric character.