pub struct MachineDeploymentRollout {
pub after: Option<String>,
pub strategy: Option<MachineDeploymentRolloutStrategy>,
}Expand description
rollout allows you to configure the behaviour of rolling updates to the MachineDeployment Machines. It allows you to require that all Machines are replaced after a certain time, and allows you to define the strategy used during rolling replacements.
Fields
after: Option<String>after is a field to indicate a rollout should be performed after the specified time even if no changes have been made to the MachineDeployment. Example: In the YAML the time can be specified in the RFC3339 format. To specify the rolloutAfter target as March 9, 2023, at 9 am UTC use “2023-03-09T09:00:00Z”.
strategy: Option<MachineDeploymentRolloutStrategy>strategy specifies how to roll out control plane Machines.