pub struct MachineDeploymentStatus {
pub available_replicas: Option<i32>,
pub conditions: Option<Vec<Condition>>,
pub deprecated: Option<MachineDeploymentStatusDeprecated>,
pub observed_generation: Option<i64>,
pub phase: Option<MachineDeploymentStatusPhase>,
pub ready_replicas: Option<i32>,
pub replicas: Option<i32>,
pub selector: Option<String>,
pub up_to_date_replicas: Option<i32>,
}Expand description
status is the observed state of MachineDeployment.
Fields
available_replicas: Option<i32>availableReplicas is the number of available replicas for this MachineDeployment. A machine is considered available when Machine’s Available condition is true.
conditions: Option<Vec<Condition>>conditions represents the observations of a MachineDeployment’s current state. Known condition types are Available, MachinesReady, MachinesUpToDate, ScalingUp, ScalingDown, Remediating, Deleting, Paused.
deprecated: Option<MachineDeploymentStatusDeprecated>deprecated groups all the status fields that are deprecated and will be removed when all the nested field are removed.
observed_generation: Option<i64>observedGeneration is the generation observed by the deployment controller.
phase: Option<MachineDeploymentStatusPhase>phase represents the current phase of a MachineDeployment (ScalingUp, ScalingDown, Running, Failed, or Unknown).
ready_replicas: Option<i32>readyReplicas is the number of ready replicas for this MachineDeployment. A machine is considered ready when Machine’s Ready condition is true.
replicas: Option<i32>replicas is the total number of non-terminated machines targeted by this deployment (their labels match the selector).
selector: Option<String>selector is the same as the label selector but in the string format to avoid introspection by clients. The string will be in the same format as the query-param syntax. More info about label selectors: http://kubernetes.io/docs/user-guide/labels#label-selectors
up_to_date_replicas: Option<i32>upToDateReplicas is the number of up-to-date replicas targeted by this deployment. A machine is considered up-to-date when Machine’s UpToDate condition is true.