pub struct MachineDeploymentStatusDeprecatedV1beta1 {
pub available_replicas: Option<i32>,
pub conditions: Option<Vec<Condition>>,
pub ready_replicas: Option<i32>,
pub unavailable_replicas: Option<i32>,
pub updated_replicas: Option<i32>,
}Expand description
v1beta1 groups all the status fields that are deprecated and will be removed when support for v1beta1 will be dropped.
Fields
available_replicas: Option<i32>availableReplicas is the total number of available machines (ready for at least minReadySeconds) targeted by this deployment.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
conditions: Option<Vec<Condition>>conditions defines current service state of the MachineDeployment.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
ready_replicas: Option<i32>readyReplicas is the total number of ready machines targeted by this deployment.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
unavailableReplicas is the total number of unavailable machines targeted by this deployment. This is the total number of machines that are still required for the deployment to have 100% available capacity. They may either be machines that are running but not yet available or machines that still have not been created.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
updated_replicas: Option<i32>updatedReplicas is the total number of non-terminated machines targeted by this deployment that have the desired template spec.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.