pub struct MachineDeploymentTemplateSpecDeletion {
pub node_deletion_timeout_seconds: Option<i32>,
pub node_drain_timeout_seconds: Option<i32>,
pub node_volume_detach_timeout_seconds: Option<i32>,
}Expand description
deletion contains configuration options for Machine deletion.
Fields
node_deletion_timeout_seconds: Option<i32>nodeDeletionTimeoutSeconds defines how long the controller will attempt to delete the Node that the Machine hosts after the Machine is marked for deletion. A duration of 0 will retry deletion indefinitely. Defaults to 10 seconds.
node_drain_timeout_seconds: Option<i32>nodeDrainTimeoutSeconds is the total amount of time that the controller will spend on draining a node.
The default value is 0, meaning that the node can be drained without any time limitations.
NOTE: nodeDrainTimeoutSeconds is different from kubectl drain --timeout
node_volume_detach_timeout_seconds: Option<i32>nodeVolumeDetachTimeoutSeconds is the total amount of time that the controller will spend on waiting for all volumes to be detached. The default value is 0, meaning that the volumes can be detached without any time limitations.