pub struct MachineHealthCheckChecksUnhealthyNodeConditions {
pub status: String,
pub timeout_seconds: i32,
pub type: String,
}Expand description
UnhealthyNodeCondition represents a Node condition type and value with a timeout specified as a duration. When the named condition has been in the given status for at least the timeout value, a node is considered unhealthy.
Fields
status: Stringstatus of the condition, one of True, False, Unknown.
timeout_seconds: i32timeoutSeconds is the duration that a node must be in a given status for, after which the node is considered unhealthy. For example, with a value of “3600”, the node must match the status for at least 1 hour before being considered unhealthy.
type: Stringtype of Node condition