pub struct MachineHealthCheckRemediationTriggerIf {
pub unhealthy_in_range: Option<String>,
pub unhealthy_less_than_or_equal_to: Option<IntOrString>,
}Expand description
triggerIf configures if remediations are triggered. If this field is not set, remediations are always triggered.
Fields
unhealthy_in_range: Option<String>unhealthyInRange specifies that remediations are only triggered if the number of unhealthy Machines is in the configured range. Takes precedence over unhealthyLessThanOrEqualTo. Eg. “[3-5]” - This means that remediation will be allowed only when: (a) there are at least 3 unhealthy Machines (and) (b) there are at most 5 unhealthy Machines
unhealthy_less_than_or_equal_to: Option<IntOrString>unhealthyLessThanOrEqualTo specifies that remediations are only triggered if the number of unhealthy Machines is less than or equal to the configured value. unhealthyInRange takes precedence if set.