pub struct MachineHealthCheckSpec {
pub checks: Option<MachineHealthCheckChecks>,
pub cluster_name: String,
pub remediation: Option<MachineHealthCheckRemediation>,
pub selector: MachineHealthCheckSelector,
}Expand description
spec is the specification of machine health check policy
Fields
checks: Option<MachineHealthCheckChecks>checks are the checks that are used to evaluate if a Machine is healthy.
Independent of this configuration the MachineHealthCheck controller will always
flag Machines with cluster.x-k8s.io/remediate-machine annotation and
Machines with deleted Nodes as unhealthy.
Furthermore, if checks.nodeStartupTimeoutSeconds is not set it is defaulted to 10 minutes and evaluated accordingly.
cluster_name: StringclusterName is the name of the Cluster this object belongs to.
remediation: Option<MachineHealthCheckRemediation>remediation configures if and how remediations are triggered if a Machine is unhealthy.
If remediation or remediation.triggerIf is not set, remediation will always be triggered for unhealthy Machines.
If remediation or remediation.templateRef is not set, the OwnerRemediated condition will be set on unhealthy Machines to trigger remediation via the owner of the Machines, for example a MachineSet or a KubeadmControlPlane.
selector: MachineHealthCheckSelectorselector is a label selector to match machines whose health will be exercised