pub struct MachineHealthCheckStatus {
pub conditions: Option<Vec<Condition>>,
pub current_healthy: Option<i32>,
pub deprecated: Option<MachineHealthCheckStatusDeprecated>,
pub expected_machines: Option<i32>,
pub observed_generation: Option<i64>,
pub remediations_allowed: Option<i32>,
pub targets: Option<Vec<String>>,
}Expand description
status is the most recently observed status of MachineHealthCheck resource
Fields
conditions: Option<Vec<Condition>>conditions represents the observations of a MachineHealthCheck’s current state. Known condition types are RemediationAllowed, Paused.
current_healthy: Option<i32>currentHealthy is the total number of healthy machines counted by this machine health check
deprecated: Option<MachineHealthCheckStatusDeprecated>deprecated groups all the status fields that are deprecated and will be removed when all the nested field are removed.
expected_machines: Option<i32>expectedMachines is the total number of machines counted by this machine health check
observed_generation: Option<i64>observedGeneration is the latest generation observed by the controller.
remediations_allowed: Option<i32>remediationsAllowed is the number of further remediations allowed by this machine health check before maxUnhealthy short circuiting will be applied
targets: Option<Vec<String>>targets shows the current list of machines the machine health check is watching