Structs
- Machine
Pool - Auto-generated derived type for MachinePoolSpec via
CustomResource - Machine
Pool Spec - spec is the desired state of MachinePool.
- Machine
Pool Status - status is the observed state of MachinePool.
- Machine
Pool Status Deprecated - deprecated groups all the status fields that are deprecated and will be removed when all the nested field are removed.
- Machine
Pool Status Deprecated V1beta1 - v1beta1 groups all the status fields that are deprecated and will be removed when support for v1beta1 will be dropped.
- Machine
Pool Status Initialization - initialization provides observations of the MachinePool initialization process. NOTE: Fields in this struct are part of the Cluster API contract and are used to orchestrate initial MachinePool provisioning.
- Machine
Pool Template - template describes the machines that will be created.
- Machine
Pool Template Metadata - metadata is the standard object’s metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
- Machine
Pool Template Spec - spec is the specification of the desired behavior of the machine. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
- Machine
Pool Template Spec Bootstrap - bootstrap is a reference to a local struct which encapsulates fields to configure the Machine’s bootstrapping mechanism.
- Machine
Pool Template Spec Bootstrap Config Ref - configRef is a reference to a bootstrap provider-specific resource that holds configuration details. The reference is optional to allow users/operators to specify Bootstrap.DataSecretName without the need of a controller.
- Machine
Pool Template Spec Deletion - deletion contains configuration options for Machine deletion.
- Machine
Pool Template Spec Infrastructure Ref - infrastructureRef is a required reference to a custom resource offered by an infrastructure provider.
- Machine
Pool Template Spec Readiness Gates - MachineReadinessGate contains the type of a Machine condition to be used as a readiness gate.
- Machine
Pool Template Spec Taints - MachineTaint defines a taint equivalent to corev1.Taint, but additionally having a propagation field.
Enums
- Machine
Pool Status Phase - status is the observed state of MachinePool.
- Machine
Pool Template Spec Readiness Gates Polarity - MachineReadinessGate contains the type of a Machine condition to be used as a readiness gate.
- Machine
Pool Template Spec Taints Effect - MachineTaint defines a taint equivalent to corev1.Taint, but additionally having a propagation field.
- Machine
Pool Template Spec Taints Propagation - MachineTaint defines a taint equivalent to corev1.Taint, but additionally having a propagation field.