pub struct MachinePoolSpec {
pub cluster_name: String,
pub failure_domains: Option<Vec<String>>,
pub provider_id_list: Option<Vec<String>>,
pub replicas: Option<i32>,
pub template: MachinePoolTemplate,
}Expand description
spec is the desired state of MachinePool.
Fields
cluster_name: StringclusterName is the name of the Cluster this object belongs to.
failure_domains: Option<Vec<String>>failureDomains is the list of failure domains this MachinePool should be attached to.
provider_id_list: Option<Vec<String>>providerIDList are the identification IDs of machine instances provided by the provider. This field must match the provider IDs as seen on the node objects corresponding to a machine pool’s machine instances.
replicas: Option<i32>replicas is the number of desired machines. Defaults to 1. This is a pointer to distinguish between explicit zero and not specified.
template: MachinePoolTemplatetemplate describes the machines that will be created.