pub struct MachinePoolStatus {
pub available_replicas: Option<i32>,
pub conditions: Option<Vec<Condition>>,
pub deprecated: Option<MachinePoolStatusDeprecated>,
pub initialization: Option<MachinePoolStatusInitialization>,
pub node_refs: Option<Vec<ObjectReference>>,
pub observed_generation: Option<i64>,
pub phase: Option<MachinePoolStatusPhase>,
pub ready_replicas: Option<i32>,
pub replicas: Option<i32>,
pub up_to_date_replicas: Option<i32>,
}Expand description
status is the observed state of MachinePool.
Fields
available_replicas: Option<i32>availableReplicas is the number of available replicas for this MachinePool. A machine is considered available when Machine’s Available condition is true.
conditions: Option<Vec<Condition>>conditions represents the observations of a MachinePool’s current state. Known condition types are Available, BootstrapConfigReady, InfrastructureReady, MachinesReady, MachinesUpToDate, ScalingUp, ScalingDown, Remediating, Deleting, Paused.
deprecated: Option<MachinePoolStatusDeprecated>deprecated groups all the status fields that are deprecated and will be removed when all the nested field are removed.
initialization: Option<MachinePoolStatusInitialization>initialization provides observations of the MachinePool initialization process. NOTE: Fields in this struct are part of the Cluster API contract and are used to orchestrate initial MachinePool provisioning.
node_refs: Option<Vec<ObjectReference>>nodeRefs will point to the corresponding Nodes if it they exist.
observed_generation: Option<i64>observedGeneration is the latest generation observed by the controller.
phase: Option<MachinePoolStatusPhase>phase represents the current phase of cluster actuation.
ready_replicas: Option<i32>readyReplicas is the number of ready replicas for this MachinePool. A machine is considered ready when Machine’s Ready condition is true.
replicas: Option<i32>replicas is the most recently observed number of replicas.
up_to_date_replicas: Option<i32>upToDateReplicas is the number of up-to-date replicas targeted by this MachinePool. A machine is considered up-to-date when Machine’s UpToDate condition is true.