pub struct MachinePoolStatusDeprecatedV1beta1 {
pub available_replicas: Option<i32>,
pub conditions: Option<Vec<Condition>>,
pub failure_message: Option<String>,
pub failure_reason: Option<String>,
pub ready_replicas: Option<i32>,
pub unavailable_replicas: Option<i32>,
}Expand description
v1beta1 groups all the status fields that are deprecated and will be removed when support for v1beta1 will be dropped.
Fields
available_replicas: Option<i32>availableReplicas is the number of available replicas (ready for at least minReadySeconds) for this MachinePool.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
conditions: Option<Vec<Condition>>conditions define the current service state of the MachinePool.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
failure_message: Option<String>failureMessage indicates that there is a problem reconciling the state, and will be set to a descriptive error message.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
failure_reason: Option<String>failureReason indicates that there is a problem reconciling the state, and will be set to a token value suitable for programmatic interpretation.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
ready_replicas: Option<i32>readyReplicas is the number of ready replicas for this MachinePool. A machine is considered ready when the node has been created and is “Ready”.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
unavailableReplicas is the total number of unavailable machine instances targeted by this machine pool. This is the total number of machine instances that are still required for the machine pool to have 100% available capacity. They may either be machine instances that are running but not yet available or machine instances that still have not been created.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.