pub struct MachinePoolTemplateSpecBootstrapConfigRef {
pub api_group: String,
pub kind: String,
pub name: String,
}Expand description
configRef is a reference to a bootstrap provider-specific resource that holds configuration details. The reference is optional to allow users/operators to specify Bootstrap.DataSecretName without the need of a controller.
Fields
api_group: StringapiGroup is the group of the resource being referenced. apiGroup must be fully qualified domain name. The corresponding version for this reference will be looked up from the contract labels of the corresponding CRD of the resource being referenced.
kind: Stringkind of the resource being referenced. kind must consist of alphanumeric characters or ‘-’, start with an alphabetic character, and end with an alphanumeric character.
name: Stringname of the resource being referenced. name must consist of lower case alphanumeric characters, ‘-’ or ‘.’, and must start and end with an alphanumeric character.