pub struct MachineSetSpec {
pub cluster_name: String,
pub deletion: Option<MachineSetDeletion>,
pub machine_naming: Option<MachineSetMachineNaming>,
pub replicas: Option<i32>,
pub selector: MachineSetSelector,
pub template: MachineSetTemplate,
}Expand description
spec is the desired state of MachineSet.
Fields
cluster_name: StringclusterName is the name of the Cluster this object belongs to.
deletion: Option<MachineSetDeletion>deletion contains configuration options for MachineSet deletion.
machine_naming: Option<MachineSetMachineNaming>machineNaming allows changing the naming pattern used when creating Machines. Note: InfraMachines & BootstrapConfigs will use the same name as the corresponding Machines.
replicas: Option<i32>replicas is the number of desired replicas. This is a pointer to distinguish between explicit zero and unspecified.
Defaults to:
- if the Kubernetes autoscaler min size and max size annotations are set:
- if it’s a new MachineSet, use min size
- if the replicas field of the old MachineSet is < min size, use min size
- if the replicas field of the old MachineSet is > max size, use max size
- if the replicas field of the old MachineSet is in the (min size, max size) range, keep the value from the oldMS
- otherwise use 1 Note: Defaulting will be run whenever the replicas field is not set:
- A new MachineSet is created with replicas not set.
- On an existing MachineSet the replicas field was first set and is now unset. Those cases are especially relevant for the following Kubernetes autoscaler use cases:
- A new MachineSet is created and replicas should be managed by the autoscaler
- An existing MachineSet which initially wasn’t controlled by the autoscaler should be later controlled by the autoscaler
selector: MachineSetSelectorselector is a label query over machines that should match the replica count. Label keys and values that must match in order to be controlled by this MachineSet. It must match the machine template’s labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
template: MachineSetTemplatetemplate is the object that describes the machine that will be created if insufficient replicas are detected. Object references to custom resources are treated as templates.