pub struct MachineSetStatusDeprecated {
pub v1beta1: Option<MachineSetStatusDeprecatedV1beta1>,
}Expand description
deprecated groups all the status fields that are deprecated and will be removed when all the nested field are removed.
Fields
v1beta1: Option<MachineSetStatusDeprecatedV1beta1>v1beta1 groups all the status fields that are deprecated and will be removed when support for v1beta1 will be dropped.