pub struct MachineSetStatusDeprecatedV1beta1 {
pub available_replicas: Option<i32>,
pub conditions: Option<Vec<Condition>>,
pub failure_message: Option<String>,
pub failure_reason: Option<String>,
pub fully_labeled_replicas: Option<i32>,
pub ready_replicas: Option<i32>,
}Expand description
v1beta1 groups all the status fields that are deprecated and will be removed when support for v1beta1 will be dropped.
Fields
available_replicas: Option<i32>availableReplicas is the number of available replicas (ready for at least minReadySeconds) for this MachineSet.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
conditions: Option<Vec<Condition>>conditions defines current service state of the MachineSet.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
failure_message: Option<String>failureMessage will be set in the event that there is a terminal problem reconciling the Machine and will contain a more verbose string suitable for logging and human consumption.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
failure_reason: Option<String>failureReason will be set in the event that there is a terminal problem reconciling the Machine and will contain a succinct value suitable for machine interpretation.
In the event that there is a terminal problem reconciling the replicas, both FailureReason and FailureMessage will be set. FailureReason will be populated with a succinct value suitable for machine interpretation, while FailureMessage will contain a more verbose string suitable for logging and human consumption.
These fields should not be set for transitive errors that a controller faces that are expected to be fixed automatically over time (like service outages), but instead indicate that something is fundamentally wrong with the MachineTemplate’s spec or the configuration of the machine controller, and that manual intervention is required. Examples of terminal errors would be invalid combinations of settings in the spec, values that are unsupported by the machine controller, or the responsible machine controller itself being critically misconfigured.
Any transient errors that occur during the reconciliation of Machines can be added as events to the MachineSet object and/or logged in the controller’s output.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
fully_labeled_replicas: Option<i32>fullyLabeledReplicas is the number of replicas that have labels matching the labels of the machine template of the MachineSet.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.
ready_replicas: Option<i32>readyReplicas is the number of ready replicas for this MachineSet. A machine is considered ready when the node has been created and is “Ready”.
Deprecated: This field is deprecated and is going to be removed when support for v1beta1 will be dropped. Please see https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more details.