pub struct MachineSetTemplateSpecTaints {
pub effect: MachineSetTemplateSpecTaintsEffect,
pub key: String,
pub propagation: MachineSetTemplateSpecTaintsPropagation,
pub value: Option<String>,
}Expand description
MachineTaint defines a taint equivalent to corev1.Taint, but additionally having a propagation field.
Fields
effect: MachineSetTemplateSpecTaintsEffecteffect is the effect for the taint. Valid values are NoSchedule, PreferNoSchedule and NoExecute.
key: Stringkey is the taint key to be applied to a node.
Must be a valid qualified name of maximum size 63 characters
with an optional subdomain prefix of maximum size 253 characters,
separated by a /.
propagation: MachineSetTemplateSpecTaintsPropagationpropagation defines how this taint should be propagated to nodes. Valid values are ‘Always’ and ‘OnInitialization’. Always: The taint will be continuously reconciled. If it is not set for a node, it will be added during reconciliation. OnInitialization: The taint will be added during node initialization. If it gets removed from the node later on it will not get added again.
value: Option<String>value is the taint value corresponding to the taint key. It must be a valid label value of maximum size 63 characters.