pub struct ClusterTopologyControlPlaneHealthCheck {
pub checks: Option<ClusterTopologyControlPlaneHealthCheckChecks>,
pub enabled: Option<bool>,
pub remediation: Option<ClusterTopologyControlPlaneHealthCheckRemediation>,
}Expand description
healthCheck allows to enable, disable and override control plane health check configuration from the ClusterClass for this control plane.
Fields
checks: Option<ClusterTopologyControlPlaneHealthCheckChecks>checks are the checks that are used to evaluate if a Machine is healthy.
If one of checks and remediation fields are set, the system assumes that an healthCheck override is defined, and as a consequence the checks and remediation fields from Cluster will be used instead of the corresponding fields in ClusterClass.
Independent of this configuration the MachineHealthCheck controller will always
flag Machines with cluster.x-k8s.io/remediate-machine annotation and
Machines with deleted Nodes as unhealthy.
Furthermore, if checks.nodeStartupTimeoutSeconds is not set it is defaulted to 10 minutes and evaluated accordingly.
enabled: Option<bool>enabled controls if a MachineHealthCheck should be created for the target machines.
If false: No MachineHealthCheck will be created.
If not set(default): A MachineHealthCheck will be created if it is defined here or in the associated ClusterClass. If no MachineHealthCheck is defined then none will be created.
If true: A MachineHealthCheck is guaranteed to be created. Cluster validation will
block if enable is true and no MachineHealthCheck definition is available.
remediation: Option<ClusterTopologyControlPlaneHealthCheckRemediation>remediation configures if and how remediations are triggered if a Machine is unhealthy.
If one of checks and remediation fields are set, the system assumes that an healthCheck override is defined, and as a consequence the checks and remediation fields from cluster will be used instead of the corresponding fields in ClusterClass.
If an health check override is defined and remediation or remediation.triggerIf is not set, remediation will always be triggered for unhealthy Machines.
If an health check override is defined and remediation or remediation.templateRef is not set, the OwnerRemediated condition will be set on unhealthy Machines to trigger remediation via the owner of the Machines, for example a MachineSet or a KubeadmControlPlane.