pub struct ClusterTopologyWorkersMachineDeployments {
pub class: String,
pub deletion: Option<ClusterTopologyWorkersMachineDeploymentsDeletion>,
pub failure_domain: Option<String>,
pub health_check: Option<ClusterTopologyWorkersMachineDeploymentsHealthCheck>,
pub metadata: Option<ClusterTopologyWorkersMachineDeploymentsMetadata>,
pub min_ready_seconds: Option<i32>,
pub name: String,
pub readiness_gates: Option<Vec<ClusterTopologyWorkersMachineDeploymentsReadinessGates>>,
pub replicas: Option<i32>,
pub rollout: Option<ClusterTopologyWorkersMachineDeploymentsRollout>,
pub taints: Option<Vec<ClusterTopologyWorkersMachineDeploymentsTaints>>,
pub variables: Option<ClusterTopologyWorkersMachineDeploymentsVariables>,
}Expand description
MachineDeploymentTopology specifies the different parameters for a set of worker nodes in the topology. This set of nodes is managed by a MachineDeployment object whose lifecycle is managed by the Cluster controller.
Fields
class: Stringclass is the name of the MachineDeploymentClass used to create the set of worker nodes.
This should match one of the deployment classes defined in the ClusterClass object
mentioned in the Cluster.Spec.Class field.
deletion: Option<ClusterTopologyWorkersMachineDeploymentsDeletion>deletion contains configuration options for Machine deletion.
failure_domain: Option<String>failureDomain is the failure domain the machines will be created in. Must match a key in the FailureDomains map stored on the cluster object.
health_check: Option<ClusterTopologyWorkersMachineDeploymentsHealthCheck>healthCheck allows to enable, disable and override MachineDeployment health check configuration from the ClusterClass for this MachineDeployment.
metadata: Option<ClusterTopologyWorkersMachineDeploymentsMetadata>metadata is the metadata applied to the MachineDeployment and the machines of the MachineDeployment. At runtime this metadata is merged with the corresponding metadata from the ClusterClass.
min_ready_seconds: Option<i32>minReadySeconds is the minimum number of seconds for which a newly created machine should be ready. Defaults to 0 (machine will be considered available as soon as it is ready)
name: Stringname is the unique identifier for this MachineDeploymentTopology. The value is used with other unique identifiers to create a MachineDeployment’s Name (e.g. cluster’s name, etc). In case the name is greater than the allowed maximum length, the values are hashed together.
readiness_gates: Option<Vec<ClusterTopologyWorkersMachineDeploymentsReadinessGates>>readinessGates specifies additional conditions to include when evaluating Machine Ready condition.
This field can be used e.g. to instruct the machine controller to include in the computation for Machine’s ready computation a condition, managed by an external controllers, reporting the status of special software/hardware installed on the Machine.
If this field is not defined, readinessGates from the corresponding MachineDeploymentClass will be used, if any.
replicas: Option<i32>replicas is the number of worker nodes belonging to this set. If the value is nil, the MachineDeployment is created without the number of Replicas (defaulting to 1) and it’s assumed that an external entity (like cluster autoscaler) is responsible for the management of this value.
rollout: Option<ClusterTopologyWorkersMachineDeploymentsRollout>rollout allows you to configure the behaviour of rolling updates to the MachineDeployment Machines. It allows you to define the strategy used during rolling replacements.
taints: Option<Vec<ClusterTopologyWorkersMachineDeploymentsTaints>>taints are the node taints that Cluster API will manage. This list is not necessarily complete: other Kubernetes components may add or remove other taints from nodes, e.g. the node controller might add the node.kubernetes.io/not-ready taint. Only those taints defined in this list will be added or removed by core Cluster API controllers.
There can be at most 64 taints. A pod would have to tolerate all existing taints to run on the corresponding node.
NOTE: This list is implemented as a “map” type, meaning that individual elements can be managed by different owners.
variables: Option<ClusterTopologyWorkersMachineDeploymentsVariables>variables can be used to customize the MachineDeployment through patches.