pub struct ClusterClassControlPlane {
pub deletion: Option<ClusterClassControlPlaneDeletion>,
pub health_check: Option<ClusterClassControlPlaneHealthCheck>,
pub machine_infrastructure: Option<ClusterClassControlPlaneMachineInfrastructure>,
pub metadata: Option<ClusterClassControlPlaneMetadata>,
pub naming: Option<ClusterClassControlPlaneNaming>,
pub readiness_gates: Option<Vec<ClusterClassControlPlaneReadinessGates>>,
pub template_ref: ClusterClassControlPlaneTemplateRef,
}Expand description
controlPlane is a reference to a local struct that holds the details for provisioning the Control Plane for the Cluster.
Fields
deletion: Option<ClusterClassControlPlaneDeletion>deletion contains configuration options for Machine deletion.
health_check: Option<ClusterClassControlPlaneHealthCheck>healthCheck defines a MachineHealthCheck for this ControlPlaneClass. This field is supported if and only if the ControlPlane provider template referenced above is Machine based and supports setting replicas.
machine_infrastructure: Option<ClusterClassControlPlaneMachineInfrastructure>machineInfrastructure defines the metadata and infrastructure information for control plane machines.
This field is supported if and only if the control plane provider template referenced above is Machine based and supports setting replicas.
metadata: Option<ClusterClassControlPlaneMetadata>metadata is the metadata applied to the ControlPlane and the Machines of the ControlPlane if the ControlPlaneTemplate referenced is machine based. If not, it is applied only to the ControlPlane. At runtime this metadata is merged with the corresponding metadata from the topology.
This field is supported if and only if the control plane provider template referenced is Machine based.
naming: Option<ClusterClassControlPlaneNaming>naming allows changing the naming pattern used when creating the control plane provider object.
readiness_gates: Option<Vec<ClusterClassControlPlaneReadinessGates>>readinessGates specifies additional conditions to include when evaluating Machine Ready condition.
This field can be used e.g. to instruct the machine controller to include in the computation for Machine’s ready computation a condition, managed by an external controllers, reporting the status of special software/hardware installed on the Machine.
NOTE: If a Cluster defines a custom list of readinessGates for the control plane, such list overrides readinessGates defined in this field. NOTE: Specific control plane provider implementations might automatically extend the list of readinessGates; e.g. the kubeadm control provider adds ReadinessGates for the APIServerPodHealthy, SchedulerPodHealthy conditions, etc.
template_ref: ClusterClassControlPlaneTemplateReftemplateRef contains the reference to a provider-specific control plane template.