pub struct ClusterClassWorkersMachineDeployments {
pub bootstrap: ClusterClassWorkersMachineDeploymentsBootstrap,
pub class: String,
pub deletion: Option<ClusterClassWorkersMachineDeploymentsDeletion>,
pub failure_domain: Option<String>,
pub health_check: Option<ClusterClassWorkersMachineDeploymentsHealthCheck>,
pub infrastructure: ClusterClassWorkersMachineDeploymentsInfrastructure,
pub metadata: Option<ClusterClassWorkersMachineDeploymentsMetadata>,
pub min_ready_seconds: Option<i32>,
pub naming: Option<ClusterClassWorkersMachineDeploymentsNaming>,
pub readiness_gates: Option<Vec<ClusterClassWorkersMachineDeploymentsReadinessGates>>,
pub rollout: Option<ClusterClassWorkersMachineDeploymentsRollout>,
}Expand description
MachineDeploymentClass serves as a template to define a set of worker nodes of the cluster
provisioned using the ClusterClass.
Fields
bootstrap: ClusterClassWorkersMachineDeploymentsBootstrapbootstrap contains the bootstrap template reference to be used for the creation of worker Machines.
class: Stringclass denotes a type of worker node present in the cluster, this name MUST be unique within a ClusterClass and can be referenced in the Cluster to create a managed MachineDeployment.
deletion: Option<ClusterClassWorkersMachineDeploymentsDeletion>deletion contains configuration options for Machine deletion.
failure_domain: Option<String>failureDomain is the failure domain the machines will be created in. Must match the name of a FailureDomain from the Cluster status. NOTE: This value can be overridden while defining a Cluster.Topology using this MachineDeploymentClass.
health_check: Option<ClusterClassWorkersMachineDeploymentsHealthCheck>healthCheck defines a MachineHealthCheck for this MachineDeploymentClass.
infrastructure: ClusterClassWorkersMachineDeploymentsInfrastructureinfrastructure contains the infrastructure template reference to be used for the creation of worker Machines.
metadata: Option<ClusterClassWorkersMachineDeploymentsMetadata>metadata is the metadata applied to the MachineDeployment and the machines of the MachineDeployment. At runtime this metadata is merged with the corresponding metadata from the topology.
min_ready_seconds: Option<i32>minReadySeconds is the minimum number of seconds for which a newly created machine should be ready. Defaults to 0 (machine will be considered available as soon as it is ready) NOTE: This value can be overridden while defining a Cluster.Topology using this MachineDeploymentClass.
naming: Option<ClusterClassWorkersMachineDeploymentsNaming>naming allows changing the naming pattern used when creating the MachineDeployment.
readiness_gates: Option<Vec<ClusterClassWorkersMachineDeploymentsReadinessGates>>readinessGates specifies additional conditions to include when evaluating Machine Ready condition.
This field can be used e.g. to instruct the machine controller to include in the computation for Machine’s ready computation a condition, managed by an external controllers, reporting the status of special software/hardware installed on the Machine.
NOTE: If a Cluster defines a custom list of readinessGates for a MachineDeployment using this MachineDeploymentClass, such list overrides readinessGates defined in this field.
rollout: Option<ClusterClassWorkersMachineDeploymentsRollout>rollout allows you to configure the behaviour of rolling updates to the MachineDeployment Machines. It allows you to define the strategy used during rolling replacements.