Module capi_machine

Module capi_machine 

Structs

Machine
Auto-generated derived type for MachineSpec via CustomResource
MachineBootstrap
bootstrap is a reference to a local struct which encapsulates fields to configure the Machine’s bootstrapping mechanism.
MachineBootstrapConfigRef
configRef is a reference to a bootstrap provider-specific resource that holds configuration details. The reference is optional to allow users/operators to specify Bootstrap.DataSecretName without the need of a controller.
MachineDeletion
deletion contains configuration options for Machine deletion.
MachineInfrastructureRef
infrastructureRef is a required reference to a custom resource offered by an infrastructure provider.
MachineReadinessGates
MachineReadinessGate contains the type of a Machine condition to be used as a readiness gate.
MachineSpec
spec is the desired state of Machine.
MachineStatus
status is the observed state of Machine.
MachineStatusAddresses
MachineAddress contains information for the node’s address.
MachineStatusDeletion
deletion contains information relating to removal of the Machine. Only present when the Machine has a deletionTimestamp and drain or wait for volume detach started.
MachineStatusDeprecated
deprecated groups all the status fields that are deprecated and will be removed when all the nested field are removed.
MachineStatusDeprecatedV1beta1
v1beta1 groups all the status fields that are deprecated and will be removed when support for v1beta1 will be dropped.
MachineStatusInitialization
initialization provides observations of the Machine initialization process. NOTE: Fields in this struct are part of the Cluster API contract and are used to orchestrate initial Machine provisioning.
MachineStatusNodeInfo
nodeInfo is a set of ids/uuids to uniquely identify the node. More info: https://kubernetes.io/docs/concepts/nodes/node/#info
MachineStatusNodeInfoSwap
Swap Info reported by the node.
MachineStatusNodeRef
nodeRef will point to the corresponding Node if it exists.
MachineTaints
MachineTaint defines a taint equivalent to corev1.Taint, but additionally having a propagation field.

Enums

MachineReadinessGatesPolarity
MachineReadinessGate contains the type of a Machine condition to be used as a readiness gate.
MachineStatusAddressesType
MachineAddress contains information for the node’s address.
MachineStatusPhase
status is the observed state of Machine.
MachineTaintsEffect
MachineTaint defines a taint equivalent to corev1.Taint, but additionally having a propagation field.
MachineTaintsPropagation
MachineTaint defines a taint equivalent to corev1.Taint, but additionally having a propagation field.