MachineDeploymentSpec

Struct MachineDeploymentSpec 

pub struct MachineDeploymentSpec {
    pub cluster_name: String,
    pub deletion: Option<MachineDeploymentDeletion>,
    pub machine_naming: Option<MachineDeploymentMachineNaming>,
    pub paused: Option<bool>,
    pub remediation: Option<MachineDeploymentRemediation>,
    pub replicas: Option<i32>,
    pub rollout: Option<MachineDeploymentRollout>,
    pub selector: MachineDeploymentSelector,
    pub template: MachineDeploymentTemplate,
}
spec is the desired state of MachineDeployment.

Fields

cluster_name: String

clusterName is the name of the Cluster this object belongs to.

deletion: Option<MachineDeploymentDeletion>

deletion contains configuration options for MachineDeployment deletion.

machine_naming: Option<MachineDeploymentMachineNaming>

machineNaming allows changing the naming pattern used when creating Machines. Note: InfraMachines & BootstrapConfigs will use the same name as the corresponding Machines.

paused: Option<bool>

paused indicates that the deployment is paused.

remediation: Option<MachineDeploymentRemediation>

remediation controls how unhealthy Machines are remediated.

replicas: Option<i32>

replicas is the number of desired machines. This is a pointer to distinguish between explicit zero and not specified.

Defaults to:

  • if the Kubernetes autoscaler min size and max size annotations are set:
    • if it’s a new MachineDeployment, use min size
    • if the replicas field of the old MachineDeployment is < min size, use min size
    • if the replicas field of the old MachineDeployment is > max size, use max size
    • if the replicas field of the old MachineDeployment is in the (min size, max size) range, keep the value from the oldMD
  • otherwise use 1 Note: Defaulting will be run whenever the replicas field is not set:
  • A new MachineDeployment is created with replicas not set.
  • On an existing MachineDeployment the replicas field was first set and is now unset. Those cases are especially relevant for the following Kubernetes autoscaler use cases:
  • A new MachineDeployment is created and replicas should be managed by the autoscaler
  • An existing MachineDeployment which initially wasn’t controlled by the autoscaler should be later controlled by the autoscaler
rollout: Option<MachineDeploymentRollout>

rollout allows you to configure the behaviour of rolling updates to the MachineDeployment Machines. It allows you to require that all Machines are replaced after a certain time, and allows you to define the strategy used during rolling replacements.

selector: MachineDeploymentSelector

selector is the label selector for machines. Existing MachineSets whose machines are selected by this will be the ones affected by this deployment. It must match the machine template’s labels.

template: MachineDeploymentTemplate

template describes the machines that will be created.