Module capi_machinepool

Module capi_machinepool 

Structs

MachinePool
Auto-generated derived type for MachinePoolSpec via CustomResource
MachinePoolSpec
spec is the desired state of MachinePool.
MachinePoolStatus
status is the observed state of MachinePool.
MachinePoolStatusDeprecated
deprecated groups all the status fields that are deprecated and will be removed when all the nested field are removed.
MachinePoolStatusDeprecatedV1beta1
v1beta1 groups all the status fields that are deprecated and will be removed when support for v1beta1 will be dropped.
MachinePoolStatusInitialization
initialization provides observations of the MachinePool initialization process. NOTE: Fields in this struct are part of the Cluster API contract and are used to orchestrate initial MachinePool provisioning.
MachinePoolTemplate
template describes the machines that will be created.
MachinePoolTemplateMetadata
metadata is the standard object’s metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
MachinePoolTemplateSpec
spec is the specification of the desired behavior of the machine. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
MachinePoolTemplateSpecBootstrap
bootstrap is a reference to a local struct which encapsulates fields to configure the Machine’s bootstrapping mechanism.
MachinePoolTemplateSpecBootstrapConfigRef
configRef is a reference to a bootstrap provider-specific resource that holds configuration details. The reference is optional to allow users/operators to specify Bootstrap.DataSecretName without the need of a controller.
MachinePoolTemplateSpecDeletion
deletion contains configuration options for Machine deletion.
MachinePoolTemplateSpecInfrastructureRef
infrastructureRef is a required reference to a custom resource offered by an infrastructure provider.
MachinePoolTemplateSpecReadinessGates
MachineReadinessGate contains the type of a Machine condition to be used as a readiness gate.
MachinePoolTemplateSpecTaints
MachineTaint defines a taint equivalent to corev1.Taint, but additionally having a propagation field.

Enums

MachinePoolStatusPhase
status is the observed state of MachinePool.
MachinePoolTemplateSpecReadinessGatesPolarity
MachineReadinessGate contains the type of a Machine condition to be used as a readiness gate.
MachinePoolTemplateSpecTaintsEffect
MachineTaint defines a taint equivalent to corev1.Taint, but additionally having a propagation field.
MachinePoolTemplateSpecTaintsPropagation
MachineTaint defines a taint equivalent to corev1.Taint, but additionally having a propagation field.